"use strict";

require("jest-dom/extend-expect");

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _reactTestingLibrary = require("react-testing-library");

var _ = require("./");

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

afterEach(_reactTestingLibrary.cleanup);

var resolveIn = function resolveIn(ms) {
  return function (value) {
    return new Promise(function (resolve) {
      return setTimeout(function () {
        return resolve(value);
      }, ms);
    });
  };
};
var resolveTo = resolveIn(0);
var rejectIn = function rejectIn(ms) {
  return function (err) {
    return new Promise(function (resolve, reject) {
      return setTimeout(function () {
        return reject(err);
      }, ms);
    });
  };
};
var rejectTo = rejectIn(0);

test("runs promiseFn on mount", function () {
  var promiseFn = jest.fn().mockReturnValue(Promise.resolve());
  (0, _reactTestingLibrary.render)(_react2.default.createElement(_2.default, { promiseFn: promiseFn }));
  expect(promiseFn).toHaveBeenCalledTimes(1);
});

test("calls promiseFn with props", function () {
  var promiseFn = jest.fn().mockReturnValue(Promise.resolve());
  (0, _reactTestingLibrary.render)(_react2.default.createElement(_2.default, { promiseFn: promiseFn, anotherProp: "123" }));
  expect(promiseFn).toHaveBeenCalledWith({ promiseFn: promiseFn, anotherProp: "123" });
});

test("passes resolved data to children as render prop", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
  var promiseFn, _render, getByText;

  return regeneratorRuntime.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          promiseFn = function promiseFn() {
            return resolveTo("done");
          };

          _render = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { promiseFn: promiseFn },
            function (_ref2) {
              var data = _ref2.data;
              return data || null;
            }
          )), getByText = _render.getByText;
          _context.next = 4;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("done");
          });

        case 4:
        case "end":
          return _context.stop();
      }
    }
  }, _callee, undefined);
})));

test("passes rejection error to children as render prop", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2() {
  var promiseFn, _render2, getByText;

  return regeneratorRuntime.wrap(function _callee2$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          promiseFn = function promiseFn() {
            return Promise.reject("oops");
          };

          _render2 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { promiseFn: promiseFn },
            function (_ref4) {
              var error = _ref4.error;
              return error || null;
            }
          )), getByText = _render2.getByText;
          _context2.next = 4;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("oops");
          });

        case 4:
        case "end":
          return _context2.stop();
      }
    }
  }, _callee2, undefined);
})));

test("passes isLoading boolean while the promise is running", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee3() {
  var promiseFn, states, _render3, getByText;

  return regeneratorRuntime.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          promiseFn = function promiseFn() {
            return resolveTo("done");
          };

          states = [];
          _render3 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { promiseFn: promiseFn },
            function (_ref6) {
              var data = _ref6.data,
                  isLoading = _ref6.isLoading;

              states.push(isLoading);
              return data || null;
            }
          )), getByText = _render3.getByText;
          _context3.next = 5;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("done");
          });

        case 5:
          expect(states).toEqual([true, true, false]);

        case 6:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3, undefined);
})));

test("passes startedAt date when the promise starts", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee4() {
  var promiseFn, _render4, getByText;

  return regeneratorRuntime.wrap(function _callee4$(_context4) {
    while (1) {
      switch (_context4.prev = _context4.next) {
        case 0:
          promiseFn = function promiseFn() {
            return resolveTo("done");
          };

          _render4 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { promiseFn: promiseFn },
            function (_ref8) {
              var startedAt = _ref8.startedAt;

              if (startedAt) {
                expect(startedAt.getTime()).toBeCloseTo(new Date().getTime(), -2);
                return "started";
              }
              return null;
            }
          )), getByText = _render4.getByText;
          _context4.next = 4;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("started");
          });

        case 4:
        case "end":
          return _context4.stop();
      }
    }
  }, _callee4, undefined);
})));

test("passes finishedAt date when the promise finishes", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee5() {
  var promiseFn, _render5, getByText;

  return regeneratorRuntime.wrap(function _callee5$(_context5) {
    while (1) {
      switch (_context5.prev = _context5.next) {
        case 0:
          promiseFn = function promiseFn() {
            return resolveTo("done");
          };

          _render5 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { promiseFn: promiseFn },
            function (_ref10) {
              var data = _ref10.data,
                  finishedAt = _ref10.finishedAt;

              if (finishedAt) {
                expect(finishedAt.getTime()).toBeCloseTo(new Date().getTime(), -1);
                return data;
              }
              return null;
            }
          )), getByText = _render5.getByText;
          _context5.next = 4;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("done");
          });

        case 4:
        case "end":
          return _context5.stop();
      }
    }
  }, _callee5, undefined);
})));

test("passes reload function that re-runs the promise", function () {
  var promiseFn = jest.fn().mockReturnValue(resolveTo());

  var _render6 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
    _2.default,
    { promiseFn: promiseFn },
    function (_ref11) {
      var reload = _ref11.reload;

      return _react2.default.createElement(
        "button",
        { onClick: reload },
        "reload"
      );
    }
  )),
      getByText = _render6.getByText;

  expect(promiseFn).toHaveBeenCalledTimes(1);
  _reactTestingLibrary.fireEvent.click(getByText("reload"));
  expect(promiseFn).toHaveBeenCalledTimes(2);
});

test("re-runs the promise when the value of 'watch' changes", function () {
  var Counter = function (_React$Component) {
    _inherits(Counter, _React$Component);

    function Counter() {
      var _temp, _this, _ret;

      _classCallCheck(this, Counter);

      for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      return _ret = (_temp = (_this = _possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.state = { count: 0 }, _this.inc = function () {
        return _this.setState(function (state) {
          return { count: state.count + 1 };
        });
      }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    Counter.prototype.render = function render() {
      return _react2.default.createElement(
        "div",
        null,
        _react2.default.createElement(
          "button",
          { onClick: this.inc },
          "increment"
        ),
        this.props.children(this.state.count)
      );
    };

    return Counter;
  }(_react2.default.Component);

  var promiseFn = jest.fn().mockReturnValue(resolveTo());

  var _render7 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
    Counter,
    null,
    function (count) {
      return _react2.default.createElement(_2.default, { promiseFn: promiseFn, watch: count });
    }
  )),
      getByText = _render7.getByText;

  expect(promiseFn).toHaveBeenCalledTimes(1);
  _reactTestingLibrary.fireEvent.click(getByText("increment"));
  expect(promiseFn).toHaveBeenCalledTimes(2);
  _reactTestingLibrary.fireEvent.click(getByText("increment"));
  expect(promiseFn).toHaveBeenCalledTimes(3);
});

test("runs deferFn only when explicitly invoked, passing arguments", function () {
  var counter = 1;
  var deferFn = jest.fn().mockReturnValue(resolveTo());

  var _render8 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
    _2.default,
    { deferFn: deferFn },
    function (_ref12) {
      var run = _ref12.run;

      return _react2.default.createElement(
        "button",
        { onClick: function onClick() {
            return run("go", counter++);
          } },
        "run"
      );
    }
  )),
      getByText = _render8.getByText;

  expect(deferFn).not.toHaveBeenCalled();
  _reactTestingLibrary.fireEvent.click(getByText("run"));
  expect(deferFn).toHaveBeenCalledWith("go", 1);
  _reactTestingLibrary.fireEvent.click(getByText("run"));
  expect(deferFn).toHaveBeenCalledWith("go", 2);
});

test("reload uses the arguments of the previous run", function () {
  var counter = 1;
  var deferFn = jest.fn().mockReturnValue(resolveTo());

  var _render9 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
    _2.default,
    { deferFn: deferFn },
    function (_ref13) {
      var run = _ref13.run,
          reload = _ref13.reload;

      return _react2.default.createElement(
        "div",
        null,
        _react2.default.createElement(
          "button",
          { onClick: function onClick() {
              return run("go", counter++);
            } },
          "run"
        ),
        _react2.default.createElement(
          "button",
          { onClick: reload },
          "reload"
        )
      );
    }
  )),
      getByText = _render9.getByText;

  expect(deferFn).not.toHaveBeenCalled();
  _reactTestingLibrary.fireEvent.click(getByText("run"));
  expect(deferFn).toHaveBeenCalledWith("go", 1);
  _reactTestingLibrary.fireEvent.click(getByText("run"));
  expect(deferFn).toHaveBeenCalledWith("go", 2);
  _reactTestingLibrary.fireEvent.click(getByText("reload"));
  expect(deferFn).toHaveBeenCalledWith("go", 2);
});

test("only accepts the last invocation of the promise", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee6() {
  var i, resolves, _render10, getByText;

  return regeneratorRuntime.wrap(function _callee6$(_context6) {
    while (1) {
      switch (_context6.prev = _context6.next) {
        case 0:
          i = 0;
          resolves = [resolveIn(10)("a"), resolveIn(20)("b"), resolveIn(10)("c")];
          _render10 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { deferFn: function deferFn(i) {
                return resolves[i];
              } },
            function (_ref15) {
              var data = _ref15.data,
                  run = _ref15.run;

              if (data) {
                expect(data).toBe("c");
                return "done";
              }
              return _react2.default.createElement(
                "button",
                { onClick: function onClick() {
                    return run(i);
                  } },
                "run"
              );
            }
          )), getByText = _render10.getByText;

          _reactTestingLibrary.fireEvent.click(getByText("run"));
          i++;
          _reactTestingLibrary.fireEvent.click(getByText("run"));
          i++;
          _reactTestingLibrary.fireEvent.click(getByText("run"));
          _context6.next = 10;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("done");
          });

        case 10:
        case "end":
          return _context6.stop();
      }
    }
  }, _callee6, undefined);
})));

test("invokes onResolve callback when promise resolves", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee7() {
  var promiseFn, onResolve;
  return regeneratorRuntime.wrap(function _callee7$(_context7) {
    while (1) {
      switch (_context7.prev = _context7.next) {
        case 0:
          promiseFn = jest.fn().mockReturnValue(Promise.resolve("ok"));
          onResolve = jest.fn();

          (0, _reactTestingLibrary.render)(_react2.default.createElement(_2.default, { promiseFn: promiseFn, onResolve: onResolve }));
          _context7.next = 5;
          return Promise.resolve();

        case 5:
          expect(onResolve).toHaveBeenCalledWith("ok");

        case 6:
        case "end":
          return _context7.stop();
      }
    }
  }, _callee7, undefined);
})));

test("invokes onReject callback when promise rejects", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee8() {
  var promiseFn, onReject;
  return regeneratorRuntime.wrap(function _callee8$(_context8) {
    while (1) {
      switch (_context8.prev = _context8.next) {
        case 0:
          promiseFn = jest.fn().mockReturnValue(Promise.reject("err"));
          onReject = jest.fn();

          (0, _reactTestingLibrary.render)(_react2.default.createElement(_2.default, { promiseFn: promiseFn, onReject: onReject }));
          _context8.next = 5;
          return Promise.resolve();

        case 5:
          expect(onReject).toHaveBeenCalledWith("err");

        case 6:
        case "end":
          return _context8.stop();
      }
    }
  }, _callee8, undefined);
})));

test("cancels pending promise when unmounted", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee9() {
  var promiseFn, onResolve, _render11, unmount;

  return regeneratorRuntime.wrap(function _callee9$(_context9) {
    while (1) {
      switch (_context9.prev = _context9.next) {
        case 0:
          promiseFn = jest.fn().mockReturnValue(Promise.resolve("ok"));
          onResolve = jest.fn();
          _render11 = (0, _reactTestingLibrary.render)(_react2.default.createElement(_2.default, { promiseFn: promiseFn, onResolve: onResolve })), unmount = _render11.unmount;

          unmount();
          _context9.next = 6;
          return Promise.resolve();

        case 6:
          expect(onResolve).not.toHaveBeenCalled();

        case 7:
        case "end":
          return _context9.stop();
      }
    }
  }, _callee9, undefined);
})));

test("can be nested", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee10() {
  var outerFn, innerFn, _render12, getByText;

  return regeneratorRuntime.wrap(function _callee10$(_context10) {
    while (1) {
      switch (_context10.prev = _context10.next) {
        case 0:
          outerFn = function outerFn() {
            return resolveIn(0)("outer");
          };

          innerFn = function innerFn() {
            return resolveIn(100)("inner");
          };

          _render12 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { promiseFn: outerFn },
            function (_ref20) {
              var outer = _ref20.data;
              return _react2.default.createElement(
                _2.default,
                { promiseFn: innerFn },
                function (_ref21) {
                  var inner = _ref21.data;

                  return outer + " " + inner;
                }
              );
            }
          )), getByText = _render12.getByText;
          _context10.next = 5;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("outer undefined");
          });

        case 5:
          _context10.next = 7;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("outer inner");
          });

        case 7:
        case "end":
          return _context10.stop();
      }
    }
  }, _callee10, undefined);
})));

test("Async.Resolved renders only after the promise is resolved", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee11() {
  var promiseFn, _render13, getByText, queryByText;

  return regeneratorRuntime.wrap(function _callee11$(_context11) {
    while (1) {
      switch (_context11.prev = _context11.next) {
        case 0:
          promiseFn = function promiseFn() {
            return resolveTo("done");
          };

          _render13 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { promiseFn: promiseFn },
            _react2.default.createElement(
              _2.default.Resolved,
              null,
              function (data) {
                return data;
              }
            )
          )), getByText = _render13.getByText, queryByText = _render13.queryByText;

          expect(queryByText("done")).toBeNull();
          _context11.next = 5;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("done");
          });

        case 5:
          expect(queryByText("done")).toBeInTheDocument();

        case 6:
        case "end":
          return _context11.stop();
      }
    }
  }, _callee11, undefined);
})));

test("Async.Loading renders only while the promise is loading", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee12() {
  var promiseFn, _render14, getByText, queryByText;

  return regeneratorRuntime.wrap(function _callee12$(_context12) {
    while (1) {
      switch (_context12.prev = _context12.next) {
        case 0:
          promiseFn = function promiseFn() {
            return resolveTo("ok");
          };

          _render14 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { promiseFn: promiseFn },
            _react2.default.createElement(
              _2.default.Loading,
              null,
              "loading"
            ),
            _react2.default.createElement(
              _2.default.Resolved,
              null,
              "done"
            )
          )), getByText = _render14.getByText, queryByText = _render14.queryByText;

          expect(queryByText("loading")).toBeInTheDocument();
          _context12.next = 5;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("done");
          });

        case 5:
          expect(queryByText("loading")).toBeNull();

        case 6:
        case "end":
          return _context12.stop();
      }
    }
  }, _callee12, undefined);
})));

test("Async.Pending renders only while the deferred promise is pending", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee13() {
  var deferFn, _render15, getByText, queryByText;

  return regeneratorRuntime.wrap(function _callee13$(_context13) {
    while (1) {
      switch (_context13.prev = _context13.next) {
        case 0:
          deferFn = function deferFn() {
            return resolveTo("ok");
          };

          _render15 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { deferFn: deferFn },
            _react2.default.createElement(
              _2.default.Pending,
              null,
              function (_ref25) {
                var run = _ref25.run;
                return _react2.default.createElement(
                  "button",
                  { onClick: run },
                  "pending"
                );
              }
            ),
            _react2.default.createElement(
              _2.default.Loading,
              null,
              "loading"
            ),
            _react2.default.createElement(
              _2.default.Resolved,
              null,
              "done"
            )
          )), getByText = _render15.getByText, queryByText = _render15.queryByText;

          expect(queryByText("pending")).toBeInTheDocument();
          _reactTestingLibrary.fireEvent.click(getByText("pending"));
          expect(queryByText("pending")).toBeNull();
          expect(queryByText("loading")).toBeInTheDocument();
          _context13.next = 8;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("done");
          });

        case 8:
          expect(queryByText("loading")).toBeNull();

        case 9:
        case "end":
          return _context13.stop();
      }
    }
  }, _callee13, undefined);
})));

test("Async.Rejected renders only after the promise is rejected", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee14() {
  var promiseFn, _render16, getByText, queryByText;

  return regeneratorRuntime.wrap(function _callee14$(_context14) {
    while (1) {
      switch (_context14.prev = _context14.next) {
        case 0:
          promiseFn = function promiseFn() {
            return rejectTo("err");
          };

          _render16 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { promiseFn: promiseFn },
            _react2.default.createElement(
              _2.default.Rejected,
              null,
              function (err) {
                return err;
              }
            )
          )), getByText = _render16.getByText, queryByText = _render16.queryByText;

          expect(queryByText("err")).toBeNull();
          _context14.next = 5;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("err");
          });

        case 5:
          expect(queryByText("err")).toBeInTheDocument();

        case 6:
        case "end":
          return _context14.stop();
      }
    }
  }, _callee14, undefined);
})));

test("Async.Resolved works also with nested Async", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee15() {
  var outer, inner, _render17, getByText, queryByText;

  return regeneratorRuntime.wrap(function _callee15$(_context15) {
    while (1) {
      switch (_context15.prev = _context15.next) {
        case 0:
          outer = function outer() {
            return resolveIn(0)("outer");
          };

          inner = function inner() {
            return resolveIn(100)("inner");
          };

          _render17 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            { promiseFn: outer },
            _react2.default.createElement(
              _2.default.Resolved,
              null,
              function (outer) {
                return _react2.default.createElement(
                  _2.default,
                  { promiseFn: inner },
                  _react2.default.createElement(
                    _2.default.Loading,
                    null,
                    outer,
                    " loading"
                  ),
                  _react2.default.createElement(
                    _2.default.Resolved,
                    null,
                    function (inner) {
                      return outer + " " + inner;
                    }
                  )
                );
              }
            )
          )), getByText = _render17.getByText, queryByText = _render17.queryByText;

          expect(queryByText("outer loading")).toBeNull();
          _context15.next = 6;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("outer loading");
          });

        case 6:
          expect(queryByText("outer inner")).toBeNull();
          _context15.next = 9;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("outer inner");
          });

        case 9:
          expect(queryByText("outer inner")).toBeInTheDocument();

        case 10:
        case "end":
          return _context15.stop();
      }
    }
  }, _callee15, undefined);
})));

test("createInstance allows setting default props", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee16() {
  var promiseFn, onResolve, CustomAsync, _render18, getByText;

  return regeneratorRuntime.wrap(function _callee16$(_context16) {
    while (1) {
      switch (_context16.prev = _context16.next) {
        case 0:
          promiseFn = function promiseFn() {
            return resolveTo("done");
          };

          onResolve = jest.fn();
          CustomAsync = (0, _.createInstance)({ promiseFn: promiseFn, onResolve: onResolve });
          _render18 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            CustomAsync,
            null,
            function (_ref29) {
              var data = _ref29.data;
              return data || null;
            }
          )), getByText = _render18.getByText;
          _context16.next = 6;
          return (0, _reactTestingLibrary.waitForElement)(function () {
            return getByText("done");
          });

        case 6:
          expect(onResolve).toHaveBeenCalledWith("done");

        case 7:
        case "end":
          return _context16.stop();
      }
    }
  }, _callee16, undefined);
})));

test("An unrelated change in props does not update the Context", _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee17() {
  var one, two, _render19, rerender;

  return regeneratorRuntime.wrap(function _callee17$(_context17) {
    while (1) {
      switch (_context17.prev = _context17.next) {
        case 0:
          one = void 0;
          two = void 0;
          _render19 = (0, _reactTestingLibrary.render)(_react2.default.createElement(
            _2.default,
            null,
            _react2.default.createElement(
              _2.default.Pending,
              null,
              function (value) {
                one = value;
              }
            )
          )), rerender = _render19.rerender;

          rerender(_react2.default.createElement(
            _2.default,
            { someProp: true },
            _react2.default.createElement(
              _2.default.Pending,
              null,
              function (value) {
                two = value;
              }
            )
          ));
          expect(one).toBe(two);

        case 5:
        case "end":
          return _context17.stop();
      }
    }
  }, _callee17, undefined);
})));